@@ -1,8 +1,9 @@
 from .input_file import InputFile
-from .file import File
+from .photosize import PhotoSize
+from .file import BaseFile
 from .document import Document
 from .audio import Audio
-from .contact import ContactMessage
+from .contact import Contact
 from .location import Location
-from .photo import Photo
 from .video import Video
+from .animation import Animation
