@@ -1,29 +1,18 @@
-"""
-MIT License
-
-Copyright (c) 2023 Kian Ahmadian
-
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
-"""
+# An API wrapper for Bale written in Python
+# Copyright (c) 2022-2024
+# Kian Ahmadian <devs@python-bale-bot.ir>
+# All rights reserved.
+#
+# This software is licensed under the GNU General Public License v2.0.
+# See the accompanying LICENSE file for details.
+#
+# You should have received a copy of the GNU General Public License v2.0
+# along with this program. If not, see <https://www.gnu.org/licenses/gpl-2.0.html>.
+from __future__ import annotations
+from typing import Optional
 class HTTPClientError:
     USER_OR_CHAT_NOT_FOUND = "no such group or user"
-    TOKEN_NOT_FOUND = "Token not found"
+    TOKEN_NOT_FOUND = "Bad Request: Token not found"
     RATE_LIMIT = "bot limit exceed"
     LOCAL_RATE_LIMIT = "local_rate_limited"
     PERMISSION_DENIED = "permission_denied"
@@ -41,6 +30,10 @@ class BaleError(Exception):
         "message",
     )
 
+    @staticmethod
+    def check_response(description: Optional[str]) -> bool:
+        return False
+
     def __init__(self, message):
         super().__init__()
         self.message = message
@@ -61,9 +54,12 @@ class InvalidToken(BaleError):
     """
     __slots__ = ("_message",)
 
-    def __init__(self):
-        super().__init__("Invalid Token")
+    def __init__(self, message=None):
+        super().__init__(message or "Invalid Token")
 
+    @staticmethod
+    def check_response(description: Optional[str]) -> bool:
+        return description and "token not found" in description.lower()
 
 class APIError(BaleError):
     """
@@ -99,8 +95,11 @@ class NotFound(BaleError):
     __slots__ = ()
 
     def __init__(self, message=None):
-        super().__init__(message if message else "Not Found")
+        super().__init__(message or "Not Found")
 
+    @staticmethod
+    def check_response(description: Optional[str]) -> bool:
+        return description and HTTPClientError.USER_OR_CHAT_NOT_FOUND in description
 
 class Forbidden(BaleError):
     """
@@ -109,8 +108,26 @@ class Forbidden(BaleError):
     """
     __slots__ = ()
 
-    def __init__(self):
-        super().__init__("Forbidden")
+    def __init__(self, message=None):
+        super().__init__(message or "Forbidden")
+
+    @staticmethod
+    def check_response(description: Optional[str]) -> bool:
+        return description and description.startswith("Forbidden:")
+
+class BadRequest(BaleError):
+    """
+    Exception that's raised for when Bale server say Bad Request.
+    Subclass of :exc:`BaleError`
+    """
+    __slots__ = ()
+
+    def __init__(self, error):
+        super().__init__(error)
+
+    @staticmethod
+    def check_response(description: Optional[str]) -> bool:
+        return description and description.startswith("Bad Request:")
 
 class RateLimited(BaleError):
     """
