@@ -1,10 +1,11 @@
-from .utils import ResponseStatusCode
 from .parser import ResponseParser
 from .http import HTTPClient, Route
+from .params import RequestParams, handle_request_param
 
 __all__ = (
 	"ResponseParser",
-	"ResponseStatusCode",
 	"Route",
 	"HTTPClient",
+	"RequestParams",
+	"handle_request_param"
 )
