@@ -1,8 +1,18 @@
+# An API wrapper for Bale written in Python
+# Copyright (c) 2022-2024
+# Kian Ahmadian <devs@python-bale-bot.ir>
+# All rights reserved.
+#
+# This software is licensed under the GNU General Public License v2.0.
+# See the accompanying LICENSE file for details.
+#
+# You should have received a copy of the GNU General Public License v2.0
+# along with this program. If not, see <https://www.gnu.org/licenses/gpl-2.0.html>.
 from aiohttp import ClientResponse
-from typing import Any
+from typing import Any, Optional, NoReturn
 from json import loads
 from json.decoder import JSONDecodeError
-
+from bale.error import NotFound, InvalidToken, Forbidden, BadRequest
 
 async def json_or_text(response: "ClientResponse"):
 	text = await response.text()
@@ -53,6 +63,11 @@ class ResponseParser:
 		self.description = description
 		self._raw = raw
 
+	def get_error(self) -> NoReturn:
+		for obj in (NotFound, InvalidToken, Forbidden, BadRequest):
+			if obj.check_response(self.description):
+				raise obj(self.description)
+
 	@classmethod
 	async def from_response(cls, data: "ClientResponse"):
 		data = await json_or_text(data)
