@@ -1,31 +1,18 @@
-"""
-MIT License
-
-Copyright (c) 2023 Kian Ahmadian
-
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
-"""
+# An API wrapper for Bale written in Python
+# Copyright (c) 2022-2024
+# Kian Ahmadian <devs@python-bale-bot.ir>
+# All rights reserved.
+#
+# This software is licensed under the GNU General Public License v2.0.
+# See the accompanying LICENSE file for details.
+#
+# You should have received a copy of the GNU General Public License v2.0
+# along with this program. If not, see <https://www.gnu.org/licenses/gpl-2.0.html>.
 import asyncio
 from typing import TYPE_CHECKING, Callable, Coroutine, Optional, NoReturn
 from bale import Update
 import logging
-from .error import InvalidToken, BaleError
+from .error import InvalidToken, BaleError, NetworkError
 
 if TYPE_CHECKING:
     from bale import Bot
@@ -46,16 +33,14 @@ class Updater:
         "bot",
         "_last_offset",
         "running",
-        "__lock",
         "interval"
     )
 
     def __init__(self, bot: "Bot"):
         self.bot = bot
         self._last_offset: Optional[int] = None
-        self.running = False
-        self.__lock = asyncio.Lock()
-        self.interval = None
+        self.running: bool = False
+        self.interval: Optional[float] = None
 
     @property
     def current_offset(self) -> Optional[int]:
@@ -71,22 +56,21 @@ class Updater:
         await self.polling()
 
     async def polling(self) -> NoReturn:
-        async with self.__lock:
-            if self.running:
-                raise RuntimeError("Updater is running")
+        if self.running:
+            raise RuntimeError("Updater is running")
 
-            if self.bot.http.is_closed():
-                raise RuntimeError("HTTPClient is Closed")
+        if self.bot.http_is_closed():
+            raise RuntimeError("HTTPClient is Closed")
 
-            self.running = True
-            self.bot.dispatch("ready")
-            _log.debug("Updater is started! (polling)")
+        self.running = True
+        self.bot.dispatch("ready")
+        _log.debug("Updater is started! (polling)")
 
-            try:
-                await self._polling()
-            except Exception as exc:
-                self.running = False
-                raise exc
+        try:
+            await self._polling()
+        except Exception as exc:
+            self.running = False
+            raise exc
 
     async def _polling(self) -> NoReturn:
         async def action_getupdates() -> bool:
@@ -123,6 +107,9 @@ class Updater:
                 except InvalidToken as exc:
                     raise exc
 
+                except NetworkError as exc:
+                    raise exc
+
                 except BaleError as exc:
                     on_error_cb(exc)
 
@@ -134,23 +121,20 @@ class Updater:
 
     async def process_update(self, update: "Update"):
         self.bot.dispatch("update", update)
-        if update.type == Update.CALLBACK_QUERY:
+        if update.callback_query:
             self.bot.dispatch("callback", update.callback_query)
-        elif update.type == Update.MESSAGE:
+        elif update.message:
             self.bot.dispatch("message", update.message)
             if update.message.successful_payment:
                 self.bot.dispatch("successful_payment", update.message.successful_payment)
+            if update.message.new_chat_members:
+                for user in update.message.new_chat_members:
+                    self.bot.dispatch("member_chat_join", update.message, update.message.chat, user)
             if update.message.left_chat_member:
                 self.bot.dispatch("member_chat_leave", update.message, update.message.chat, update.message.left_chat_member)
-            for user in update.message.new_chat_members or []:
-                self.bot.dispatch("member_chat_join", update.message, update.message.chat, user)
-        elif update.type == Update.EDITED_MESSAGE:
-            self.bot.dispatch("edited_message", update.edited_message)
+        elif update.edited_message:
+            self.bot.dispatch("message_edit", update.edited_message)
 
     async def stop(self):
         """Stop running and Stop `poll_event` loop"""
-        async with self.__lock:
-            if not self.running:
-                raise RuntimeError("Updater is not running")
-
-            self.running = False
+        self.running = False
